@@ -104,6 +104,7 @@ if sys.version_info >= (3, 8):
             "pattern": Optional[str],
             "pattern-prefix": Optional[str],
             "latest-tag": bool,
+            "highest-tag": bool,
             "substitution": _Substitution,
             "files": Mapping[str, _File],
             "style": Optional[str],
@@ -120,6 +121,8 @@ if sys.version_info >= (3, 8):
             "fix-shallow-repository": bool,
             "ignore-untracked": bool,
             "commit-length": Optional[int],
+            "commit-prefix": Optional[str],
+            "escape-with": Optional[str],
             "from-file": _FromFile,
         },
     )
@@ -232,6 +235,7 @@ def _default_config() -> Mapping:
                 "pattern": None,
                 "pattern-prefix": None,
                 "latest-tag": False,
+                "highest-tag": False,
                 "substitution": {
                     "files": ["*.py", "*/__init__.py", "*/__version__.py", "*/_version.py"],
                     "patterns": [
@@ -258,6 +262,8 @@ def _default_config() -> Mapping:
                 "fix-shallow-repository": False,
                 "ignore-untracked": False,
                 "commit-length": None,
+                "commit-prefix": None,
+                "escape-with": None,
                 "from-file": {
                     "source": None,
                     "pattern": None,
@@ -505,6 +511,7 @@ def _get_version_from_dunamai(
         vcs=vcs,
         pattern=pattern,
         latest_tag=config["latest-tag"],
+        highest_tag=config["highest-tag"],
         tag_dir=config["tag-dir"],
         tag_branch=config["tag-branch"],
         full_commit=config["full-commit"],
@@ -563,6 +570,8 @@ def _get_version(config: _Config, name: Optional[str] = None) -> Tuple[str, Vers
             format=config["format"],
             style=style,
             tagged_metadata=config["tagged-metadata"],
+            commit_prefix=config["commit-prefix"],
+            escape_with=config["escape-with"],
         )
 
     return (serialized, version)
@@ -760,7 +769,7 @@ def _revert_version(retain: bool = False) -> None:
             persistent = []
             for file, file_info in config["files"].items():
                 if file_info["persistent-substitution"]:
-                    persistent.append(state.path.parent.joinpath(file))
+                    persistent.append(state.path.parent.joinpath(file).resolve())
 
             for file, content in state.substitutions.items():
                 if file in persistent:
